@@ -386,7 +386,7 @@ tw_get_cached_wikipedia_page_links <- function(title,
   db_result <- tryCatch(
     dplyr::tbl(src = db, table_name) %>%
       dplyr::filter(
-        .data$source_title_url %in% stringr::str_c(title)
+        .data$source_title_url %in% !!stringr::str_c(title)
       ),
     error = function(e) {
       logical(1L)
