@@ -5,19 +5,24 @@
 #' @param url A character vector with the full URL to one or more Wikipedia pages. If given, title and language can be left empty.
 #' @param title Title of a Wikipedia page or final parts of its url. If given, url can be left empty, but language must be provided.
 #' @param language Two-letter language code used to define the Wikipedia version to use. Defaults to language set with `tw_set_language()`; if not set, "en". If url given, this can be left empty.
-#' @param action Defaults to "query". Usually either "query" or "parse". In principle, any valid action value, see: "https://www.mediawiki.org/w/api.php"
+#' @param action Defaults to "query". Usually either "query" or "parse". In principle, any valid action value, see: \url{https://www.mediawiki.org/w/api.php}
+#' @param type Defaults to "page". Either "page" or "category".
 #'
 #' @return A character vector of base urls to be used with the MediaWiki API
 #' @export
 #'
 #' @examples
-#' if (interactive()) {
-#'   tw_get_wikipedia_base_api_url(title = "Margaret Mead", language = "en")
-#' }
+#' tw_get_wikipedia_base_api_url(title = "Margaret Mead", language = "en")
+#' tw_get_wikipedia_base_api_url(
+#'   title = "Category:American women anthropologists",
+#'   type = "category",
+#'   language = "en"
+#' )
 tw_get_wikipedia_base_api_url <- function(url = NULL,
                                           title = NULL,
                                           language = tidywikidatar::tw_get_language(),
-                                          action = "query") {
+                                          action = "query",
+                                          type = "page") {
   if (is.null(url) == TRUE) {
     if (is.null(title) == TRUE) {
       usethis::ui_stop("Either url or title must be provided")
@@ -45,15 +50,30 @@ tw_get_wikipedia_base_api_url <- function(url = NULL,
     title_reference <- "&titles="
   }
 
-  api_url <- stringr::str_c(
-    "https://",
-    language,
-    ".wikipedia.org/w/api.php?action=",
-    action,
-    "&redirects=true&format=json",
-    title_reference,
-    utils::URLencode(URL = title)
-  )
+  if (type == "page") {
+    api_url <- stringr::str_c(
+      "https://",
+      language,
+      ".wikipedia.org/w/api.php?action=",
+      action,
+      "&redirects=true&format=json",
+      title_reference,
+      utils::URLencode(URL = title)
+    )
+  } else if (type == "category") {
+    title_reference <- "&cmtitle="
+
+    api_url <- stringr::str_c(
+      "https://",
+      language,
+      ".wikipedia.org/w/api.php?action=",
+      action,
+      "&redirects=true&format=json",
+      title_reference,
+      utils::URLencode(URL = title),
+      "&list=categorymembers"
+    )
+  }
 
   api_url
 }
@@ -518,7 +538,7 @@ tw_get_cached_wikipedia_page_qid <- function(title,
   db_result <- tryCatch(
     dplyr::tbl(src = db, table_name) %>%
       dplyr::filter(
-        .data$title_url %in% stringr::str_c(title_url)
+        .data$title_url %in% !!stringr::str_c(title_url)
       ),
     error = function(e) {
       logical(1L)
